Evaluates the evidence lower bound for a given dynamic network.
expSBM_ELBO(N, edgelist, Z, lambda, mu, nu, directed = F, trunc = T, verbose = F)Number of nodes.
A matrix with 4 columns: on the first column the sender node, on the second the receiver, on the third either a one or zero to indicate whether it is an interaction or a non-interaction respectively, on the fourth the corresponding exponential length.
A NxK matrix indicating a soft clustering of the nodes into the K latent groups. The generic entry in position [i,k] represents the posterior probability that node i belongs to group k.
Mixing proportions of the latent groups.
A matrix of size KxK indicating the exponential rates for the interaction lengths, for each pair of groups. Must be a symmetric matrix if directed is false.
A matrix of size KxK indicating the exponential rates for the non-interaction lengths, for each pair of groups. Must be a symmetric matrix if directed is false.
TRUE or FALSE indicating whether interactions have an orientation or not.
TRUE or FALSE indicating whether the first and last interactions or non-interactions for every edge are assumed to be truncated or not.
TRUE or FALSE indicating whether a lengthy output should be printed out.
Number of seconds required for the evaluation.
Value of the evidence lower bound for the given variational parameters.